""" cli interface """

from . import cli

if __name__ == "__main__":
    cli()
